#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-ormolu-plugin
version:              2.2.0.0
visibility:           public
id:                   hls-ormolu-plugin-2.2.0.0-FThqCPtuHui6xqAMNii05z
key:                  hls-ormolu-plugin-2.2.0.0-FThqCPtuHui6xqAMNii05z
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  da4b2b3196b7db4c9f3199b6f4c83017
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-2.2.0.0-FThqCPtuHui6xqAMNii05z
depends:
    base-4.18.2.1 extra-1.7.16-6e0wBrlA2xu66mkOtGwbe0
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-th-9.6.6
    ghcide-2.2.0.0-KYWvlbTD7z45Iv81bcdI4A
    hls-plugin-api-2.2.0.0-8OOoB6gEqmT4UEewr4ZH15
    lens-5.3.3-Ag3JywAjDxJ2k98xBhf4hs lsp-2.2.0.0-1wTjR6m8XHMB9d0XTUKi2
    mtl-2.3.1 ormolu-0.6.0.0-DWj0gZFrOgfKRhuggJiKiA text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

